<?php

namespace POOPETPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H2_Pricing_Block extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'poopet_h2_pricing_block';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H2 Pricing Block', 'poopet' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'poopet' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h2_pricing_block',
			[
				'label' => esc_html__( 'H2 Pricing Block', 'poopet' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		
		$this->end_controls_section();
		
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'List Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'title',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'ff_sing',
					[
					'label' => __( 'Counter Sing', 'rashid' ),
					'type' => Controls_Manager::TEXTAREA,
					'dynamic' => [
					'active' => true,
					],
					'placeholder' => __( 'Enter Counter Sing', 'rashid' ),
					]
				);
				$this->add_control(
					'ff_price',
					[
					'label' => __( 'Counter Price', 'rashid' ),
					'type' => Controls_Manager::TEXTAREA,
					'dynamic' => [
					'active' => true,
					],
					'placeholder' => __( 'Enter Counter Sing', 'rashid' ),
					]
				);
				$this->add_control(
					'subtitle',
					[
						'label'       => __( 'Sub Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Sub title', 'rashid' ),
					]
				);
				$this->add_control(
					'bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'btnlink',
					[
					  'label' => __( 'Button Url', 'rashid' ),
					  'type' => Controls_Manager::URL,
					  'placeholder' => __( 'https://your-link.com', 'rashid' ),
					  'show_external' => true,
					  'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => true,
					  ],
					
				   ]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();
		
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<section class="pricing-section <?php echo esc_attr($settings['sec_class']);?>"> 
			<div class="container">
				<div class="inner-content">
					<div class="row">
						<div class="col-lg-12 pricing-column wow fadeInUp" data-wow-delay="00ms" data-wow-duration="1500ms">
							<div class="pricing-table centred">
								<div class="table-header">
									<div class="title"><?php echo $settings['title'];?></div>
									<div class="price"><?php echo esc_attr($settings['ff_sing']);?><?php echo esc_attr($settings['ff_price']);?><span><?php echo $settings['subtitle'];?></span></div>
								</div>
								<div class="table-content">
									<ul>
										<?php foreach($settings['repeat'] as $item):?>
										<li><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
										<?php endforeach; ?>
									</ul>
								</div>
								<?php if($settings['bttn']): ?>
								<div class="table-footer">
									<a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="theme-btn"><?php echo $settings['bttn'];?></a>
								</div>
								<?php endif; ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
             
		<?php 
	}

}