<?php

namespace POOPETPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */

class H2_Team extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'poopet_h2_team';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H2 Team', 'poopet' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'poopet' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h2_team',
			[
				'label' => esc_html__( 'H2 Team', 'poopet' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'poopet' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'poopet' ),
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'poopet' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'poopet' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'poopet' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'poopet' ),
			]
		);
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'poopet' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'poopet' ),
					'6'   => esc_html__( 'Two Column', 'poopet' ),
					'4'   => esc_html__( 'Three Column', 'poopet' ),
					'3'   => esc_html__( 'Four Column', 'poopet' ),
					'2'   => esc_html__( 'Six Column', 'poopet' ),
				),
			]
		);
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'poopet' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'poopet' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'poopet' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'poopet' ),
					'title'      => esc_html__( 'Title', 'poopet' ),
					'menu_order' => esc_html__( 'Menu Order', 'poopet' ),
					'rand'       => esc_html__( 'Random', 'poopet' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'poopet' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'poopet' ),
					'ASC'  => esc_html__( 'ASC', 'poopet' ),
				),
			]
		);
		$this->add_control(
			'query_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'poopet' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude posts, pages, etc. by ID with comma separated.', 'poopet' ),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'poopet'),
				  'options' => get_team_categories()
				]
		);
		
		
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        
        $paged = poopet_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-poopet' );
		$args = array(
			'post_type'      => 'poopet_team',
			'posts_per_page' => poopet_set( $settings, 'query_number' ),
			'orderby'        => poopet_set( $settings, 'query_orderby' ),
			'order'          => poopet_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if ( poopet_set( $settings, 'query_exclude' ) ) {
			$settings['query_exclude'] = explode( ',', $settings['query_exclude'] );
			$args['post__not_in']      = poopet_set( $settings, 'query_exclude' );
		}
		if( poopet_set( $settings, 'query_category' ) ) $args['team_cat'] = poopet_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{
		?>
  
		<section class="team-style-two gray-bg centred <?php echo esc_attr($settings['sec_class']);?>">
			<div class="container">
				<?php if($settings['title']): ?>
				<div class="sec-title alternate-color">
					<div class="top-title"><?php echo $settings['subtitle'];?></div>
					<h1><?php echo $settings['title'];?></h1>
				</div>
				<?php endif; ?>
				<div class="row">
				
					<?php while ( $query->have_posts() ) : $query->the_post(); ?>
					
					<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12 staff-column">
						<div class="team-block-one wow fadeInUp" data-wow-delay="00ms" data-wow-duration="1500ms">
							<figure class="image-box">
								<a href="<?php echo esc_url(get_post_meta( get_the_id(), 'team_link', true ));?>">
									<?php the_post_thumbnail(); ?>
								</a>
							</figure>
							<div class="lower-content">
								<h3><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'team_link', true ));?>"><?php the_title(); ?></a></h3>
								<span class="designation"><?php echo (get_post_meta( get_the_id(), 'designation', true ));?></span>
								<?php	
								$icons = get_post_meta( get_the_id(), 'social_profile', true );
								if ( ! empty( $icons ) ) :?>
								<ul class="social-style-one">
									<?php
									foreach ( $icons as $h_icon ) :
									$header_social_icons = json_decode( urldecode( poopet_set( $h_icon, 'data' ) ) );
									if ( poopet_set( $header_social_icons, 'enable' ) == '' ) {
									continue;
									}
									$icon_class = explode( '-', poopet_set( $header_social_icons, 'icon' ) );?>
									<li><a href="<?php echo poopet_set( $header_social_icons, 'url' ); ?>"><i class="fab <?php echo esc_attr( poopet_set( $header_social_icons, 'icon' ) ); ?>"></i></a></li>
									<?php endforeach; ?>
								</ul>
								<?php endif; ?>
							</div>
						</div>
					</div>
					
					<?php endwhile; ?>
					
				</div>
			</div>
		</section>
  
           
        <?php }
		wp_reset_postdata();
	}

}