<?php

namespace POOPETPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Partner extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'poopet_partner';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Partner', 'poopet' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'poopet' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'partner',
			[
				'label' => esc_html__( 'Partner', 'poopet' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'poopet' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'return_value' => 'style1',
                    'default'      => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'poopet' ),
						'style2' => esc_html__( 'Choose Style 2', 'poopet' ),
					),
				]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'number',
			[
				'label'       => __( 'Number', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Number', 'rashid' ),
			]
		);
		$this->add_control(
			'title1',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'conditions' => array(
						'relation' => 'or',
						'terms'    => array(
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style2',
							),
						),
					),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'conditions' => array(
						'relation' => 'or',
						'terms'    => array(
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style2',
							),
						),
					),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();

		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Skill Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								'block_title' =>
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								'ff_stop' =>
								[
									'name' => 'ff_stop',
									'label' => esc_html__('Counter Stop', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								'ff_sing' =>
								[
									'name' => 'ff_sing',
									'label' => esc_html__('Counter Sing', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		<?php  if ( 'style1' === $settings['style'] ) : ?>
        
		<div class="partner-section-003 p_relative pt_120 pb_200 <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
			<div class="bg-layer p_absolute l_0 parallax_none parallax-bg" data-parallax='{"y": 50}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">       
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
			<div class="auto-container">
				<div class="content-box">
					<div class="row">
						<?php if($settings['title']): ?>
						<div class="col-lg-6 col-md-12 col-sm-12">
							<div class="content-left pt_10">
								<h6><?php echo $settings['subtitle'];?></h6>
								<h1><?php echo $settings['title'];?></h1>
							</div>
						</div>
						<?php endif; ?>
						<div class="col-lg-6 col-md-12 col-sm-12">
							<div class="content-right">
								<div class="border">
									<div class="happy-customer">
										<i class="flaticon-satisfaction"></i>
										<h1><?php echo $settings['number'];?></h1>
										<h6><?php echo $settings['title1'];?></h6>
									</div>
								</div>
								<div class="text-area">
									<div class="text mb_20"><?php echo $settings['text'];?></div>
									
									<div class="progress-inner p_relative d_block wow fadeInUp" data-wow-duration="1500ms">
									
										<?php foreach($settings['repeat'] as $item):?>
									
										<div class="progress-box p_relative d_block mb_25">
											<h6><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
											<div class="bar">
												<div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"><div class="count-text"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div></div>
											</div>
										</div>
										
										<?php endforeach; ?>
										
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<div class="partner-section-004 p_relative <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
			<div class="bg-layer p_absolute l_0 parallax_none parallax-bg" data-parallax='{"y": 50}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);"> 
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
			<div class="content-inner">
				<div class="auto-container">
					<div class="row">
						<div class="col-lg-7 col-md-7 col-sm-12">
							<div class="content-box">
								<h6 class="sub-title"><?php echo $settings['subtitle'];?></h6>
								<h1><?php echo $settings['title'];?></h1>
								<div class="text"><?php echo $settings['text'];?></div>
								
								<div class="progress-inner p_relative d_block wow fadeInUp" data-wow-duration="1500ms">
								
									<?php foreach($settings['repeat'] as $item):?>
								
									<div class="progress-box p_relative d_block mb_30">
										<h6><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
										<div class="bar">
											<div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"><div class="count-text"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div></div>
										</div>
									</div>
									
									<?php endforeach; ?>
									
								</div>
							</div>
						</div>
						<div class="col-lg-5 col-md-5 col-sm-12">
							<div class="image-box">
								<figure>
									<?php  if ( esc_url($settings['image']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		
		<?php endif;?>
             
		<?php 
	}

}