<?php

namespace POOPETPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service2 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'poopet_service2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service 2', 'poopet' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'poopet' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'service2',
			[
				'label' => esc_html__( 'Service 2', 'poopet' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'poopet' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'return_value' => 'style1',
                    'default'      => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'poopet' ),
						'style2' => esc_html__( 'Choose Style 2', 'poopet' ),
					),
				]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();

		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Service Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					  'repeat', 
						[
							'type' => Controls_Manager::REPEATER,
							'seperator' => 'before',
							'default' => 
								[
									['block_title' => esc_html__('Projects Completed', 'rashid')],
								],
							'fields' => 
								[
									'block_column' =>
									[
										'name' => 'block_column',
										'label'   => esc_html__( 'Column', 'rashid' ),
										'type'    => Controls_Manager::NUMBER,
										'default' => 2,
										'min'     => 1,
										'max'     => 12,
										'step'    => 1,
									],
									'block_icons' =>
									[
										'name' => 'block_icons',
										'label' => esc_html__('Enter The icons', 'rashid'),
										'type' => Controls_Manager::SELECT,
										'options'  => get_fontawesome_icons(),
									],
									'block_image' =>
									[
										'name' => 'block_image',
										'label' => __( 'Image', 'rashid' ),
										'type' => Controls_Manager::MEDIA,
										'default' => ['url' => Utils::get_placeholder_image_src(),],
									],
									'block_alt_text' =>
									[
										'name' => 'block_alt_text',
										'label' => esc_html__('Alt Text', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
									'block_title' =>
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
									'block_text' =>
									[
										'name' => 'block_text',
										'label' => esc_html__('Text', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
									'block_button' =>
									[
										'name' => 'block_button',
										'label'       => __( 'Button', 'rashid' ),
										'type'        => Controls_Manager::TEXT,
										'dynamic'     => [
											'active' => true,
										],
										'placeholder' => __( 'Enter your Button Title', 'rashid' ),
									],
									'block_btnlink' =>
									[
										'name' => 'block_btnlink',
										'label' => __( 'Button Url', 'rashid' ),
										'type' => Controls_Manager::URL,
										'placeholder' => __( 'https://your-link.com', 'rashid' ),
										'show_external' => true,
										'default' => [
										'url' => '',
										'is_external' => true,
										'nofollow' => true,
										],
									],
								],
							'title_field' => '{{block_title}}',
						 ]
				);
				
				
		$this->end_controls_section();	
		
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
		<section class="service-section-003 <?php echo esc_attr($settings['sec_class']);?>">
			<div class="auto-container">
				<?php if($settings['title']): ?>
				<div class="section-title centred">
					<span><?php echo $settings['subtitle'];?></span>
					<h1><?php echo $settings['title'];?></h1>
				</div>
				<?php endif; ?>
				<div class="row">
				
					<?php foreach($settings['repeat'] as $item):?>
				
					<div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12">
						<div class="service-item-003 centred img_hover_3">
							<figure class="image-box">
								<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</figure>
							<div class="image-content">
								<h2><?php echo wp_kses($item['block_title'], $allowed_tags);?></h2>
								<div class="text"><?php echo wp_kses($item['block_text'], $allowed_tags);?></div>
								<div class="info-btn clearfix">
									<div class="icon">
										<i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i>
									</div>
									<?php if(wp_kses($item['block_button'], $allowed_tags)): ?>
									<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="btn-one"><?php echo wp_kses($item['block_button'], $allowed_tags);?></a>
									<?php endif; ?>
								</div>
							</div>
						</div>
					</div>
					
					<?php endforeach; ?>
					
				</div>
			</div>
		</section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
		<section class="service-section-003 <?php echo esc_attr($settings['sec_class']);?>" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
		<?php else :?>	
		<div class="noimage">
		<?php endif;?>
		
			<div class="auto-container">
				<?php if($settings['title']): ?>
				<div class="section-title centred">
					<span><?php echo $settings['subtitle'];?></span>
					<h1><?php echo $settings['title'];?></h1>
				</div>
				<?php endif; ?>
				<div class="row">
				
					<?php foreach($settings['repeat'] as $item):?>
				
					<div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12">
						<div class="service-item-004 centred">
							<div class="image-content">
								<div class="icon-box">
									<div class="icon"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
								</div>
								<h2><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h2>
								<div class="text"><?php echo wp_kses($item['block_text'], $allowed_tags);?></div>
							</div>
						</div>
					</div>
					
					<?php endforeach; ?>
					
				</div>
			</div>
		</section>
		
		<?php endif;?>
             
		<?php 
	}

}